<?php
/*
Plugin Name: Current Location
Plugin URI: http://jdg.futbal.net/index.php/current-location-plugin/?from=current_location-plugin
Description: Gets your current location from <a href="http://www.google.com/latitude/apps/badge">Google Badge System</a>. Use <code>&lt;?php echo display_current_location(); ?&gt;</code> to display your current location.
Version: 1.5.5
Author: Justin D. Givens
Author URI: http://jdg.futbal.net/?from=author_name-plugin
Copyright 2011 Justin D. Givens

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
$CL_Version = "1.5.5";
DEFINE('CL_VERSION', "1.5.5");

load_plugin_textdomain('current-location', 'wp-content/plugins/current-location/locale');

include('cl-function.php');
include('cl-post.php');
include('cl-widget.php');
include('cl-editor-plugin.php');

function fixDate($incoming_timeStamp) {
	global $wp_version;
	//Function to take in the GMT and fix the time.
	//Set the timezone default if you are using WP 2.8 or higher.
	//If you don't have 2.8 or higher then it unix timestamp will return the server time. Not the Blog local time. 
	if ($wp_version >= 2.8)
	{
		date_default_timezone_set(get_option('timezone_string'));
	}
	return $incoming_timeStamp;
}

function cl_options() {
	global $CL_Version, $wp_version;
	$update = false;
	$options = get_option("current_location_plugin");
	if (!is_array($options)) {
		$options["current_location_userid"] = "Enter Here";
		$options["current_location_date"] = "M d, Y g:i a";
		$options["current_location_temp_check"] = "";
		$options["current_location_temp_location"] = "";
		$options["current_location_map_width"] = "180";
		$options["current_location_map_height"] = "300";
		$options["current_location_map_type"] = "road";
		$options["current_location_map_zoom"] = "10";
	}

	// If the user has submitted their options, grab them here.
	if ($_POST['CL_SAVE']) {
		//Main settings were updated/saved.
		$options["current_location_userid"] = htmlspecialchars(trim($_POST["user_id"]));
		$options["current_location_date"] = htmlspecialchars(trim($_POST["format_date"]));
		$options["current_location_temp_check"] = htmlspecialchars($_POST["temp_check"]);
		//Checking to see if vacation is checked. 
		if ($options["current_location_temp_check"] == "Vac")
		{
			$options["current_location_temp_location"] = htmlspecialchars(trim($_POST["temp_location"]));
		} else {
			$options["current_location_temp_location"] = "";
		}
		//Map settings were updated/saved. 
		$width = htmlspecialchars(trim($_POST["maps_width"]));
		$height = htmlspecialchars(trim($_POST["maps_height"]));
		if ($width == "") { $width = "180"; }
		if ($height == "") { $height = "300"; }
		$options["current_location_map_width"] = $width;
		$options["current_location_map_height"] = $height;
		$options["current_location_map_type"] = htmlspecialchars(trim($_POST["maps_type"]));
		$options["current_location_map_zoom"] = htmlspecialchars(trim($_POST["maps_zoom"]));
		
		//Save the settings into the WP Options Table.
		update_option("current_location_plugin", $options);
		$update = true;
	}
	
	if ($wp_version >= 2.8)
	{
		$cl_timezone = get_option('timezone_string');
		if ($cl_timezone == "")
		{
			$cl_timezone = __("Timezone not set. Go to Settings > General");
		}
	} else {
		$cl_timezone = __("Since you are using an older version of WordPress $wp_version, the timestamp output will be set to the server.");
	}

	$id = $options["current_location_userid"];
	$format_date = $options["current_location_date"];
	$temp_check = $options["current_location_temp_check"];
	$temp_location = $options["current_location_temp_location"];
	$temp_width = $options["current_location_map_width"];
	$temp_height = $options["current_location_map_height"];
	$temp_type = $options["current_location_map_type"];
	$temp_zoom = $options["current_location_map_zoom"];
	
	
	///Testing to see if Vacation is turned on. If so check it and fill in the info. If no, don't display anything.
	if ($temp_check == "Vac") { 
		$temp_check1 = "checked=\"checked\""; 
		$temp_location = $options["current_location_temp_location"]; 
	} else {
		$temp_check1 = "";
		$temp_location = "";
	}
	
?>
<div class="wrap" id="current-location">
  <div style="background:transparent url(<?php echo WP_PLUGIN_URL . '/current-location';?>/icon32.png) no-repeat;float:left;height:36px;margin:14px 6px 0 0;width:36px;"><br /></div> 
	<h2>Current Location <?php echo $CL_Version;?></h2>
  <p><?php printf(__("New in Current Location %s: Added a TinyMCE Button to the Post/Page Editor. %s: Starting working on the ability to I18n this plugin."), $CL_Version, "1.5.4"); ?></p>
  <h3 style="margin:auto 0px; margin-bottom:10px; margin-top:10px; width:100%; text-align:center;">Current Location <?php _e("Settings"); ?></h3>
	<?php if ($update) { ?><p style="color:green;font-size:14px;"><?php _e("Settings Saved."); ?></p><? } ?>
  <div class="clear"></div>
  <form id="cl_formOptions" name="cl_formOptions" method="post" action="">
  <table class="widefat" cellspacing="0"> 
  	<thead>
    	<tr>
      	<th width="15%"><?php _e("Field"); ?></th>
        <th><?php _e("Value"); ?></th>
      </tr>
    </thead>
    <tfoot>
    	<tr>
      	<td colspan="2"><input type="submit" class="primary" name="CL_SAVE" id="CL_SAVE" value="<?php _e("Save Changes"); ?>" /></td>
      </tr>
    	<tr>
      	<th width="15%"><?php _e("Field"); ?></th>
        <th><?php _e("Value"); ?></th>
      </tr>
    </tfoot>
    <tbody>
    	<tr class="settings">
      	<td><label for="user_id"><?php _e("User ID"); ?>:</label></td>
        <td><input name="user_id" type="text" id="user_id" size="25" value="<?php echo $id; ?>" /></td>
      </tr>
      <tr class="explain">
      	<td>&nbsp;</td>
      	<td><?php _e("Get your User ID from here");?>: <a target="_blank" title="<?php _e("Google Badge System"); ?>" href="http://www.google.com/latitude/apps/badge"><?php _e("Google Badge System"); ?></a>. <?php _e("Its is the ID number after"); ?> "api?user=". <br /><strong><?php _e("Example"); ?>:</strong> http://www.google.com/latitude/apps/badge/api?user=-123456789&type=json <?php _e("User ID is"); ?>: <strong>-123456789</strong></td>
      </tr>
    	<tr class="settings">
      	<td><label for="format_date"><?php _e("Date Format"); ?>:</label></td>
        <td><input name="format_date" type="text" id="format_date" size="25" value="<?php echo $format_date; ?>" /></td>
      </tr>
      <tr class="explain">
      	<td>&nbsp;</td>
      	<td><?php _e("Default Format is"); ?>: <strong>M j, Y g:i a</strong>. <?php _e("Use the"); ?> <a target="_blank" title="PHP Date" href="http://us3.php.net/manual/en/function.date.php">PHP Date</a> <?php _e("page to learn how to do different formating."); ?><br /><br /><?php _e("Current Timezone"); ?>: <strong><a href="./options-general.php" title="<?php _e("Change the Timezone here."); ?>"><?php echo $cl_timezone; ?></a></strong></td>
      </tr>
    	<tr class="settings">
      	<td><label for="temp_location"><?php _e("Vacation Text"); ?>:</label></td>
        <td><input style="position:relative;margin-top:0px;margin-right:5px;" name="temp_check" type="checkbox" id="temp_check" value="Vac" <?php echo $temp_check1; ?> /><input name="temp_location" type="text" id="temp_location" size="30" value="<?php echo $temp_location; ?>" /></td>
      </tr>
      <tr class="explain">
      	<td>&nbsp;</td>
      	<td><?php _e("Sometimes you don't want to update your location (example: vacation). Check this box below and manually enter a location or message."); ?></td>
      </tr>
    	<tr class="settings">
      	<td><label for="maps_width"><?php _e("Map/Static Width"); ?>:</label></td>
        <td><input name="maps_width" type="text" id="maps_width" size="5" value="<?php echo $temp_width; ?>" /></td>
      </tr>
      <tr class="explain">
      	<td>&nbsp;</td>
      	<td><?php _e("Default Setting is"); ?>: <strong>180</strong></td>
      </tr>
    	<tr class="settings">
      	<td><label for="maps_height"><?php _e("Map/Static Height"); ?>:</label></td>
        <td><input name="maps_height" type="text" id="maps_height" size="5" value="<?php echo $temp_height; ?>" /></td>
      </tr>
      <tr class="explain">
      	<td>&nbsp;</td>
      	<td><?php _e("Default Setting is"); ?>: <strong>300</strong></td>
      </tr>
    	<tr class="settings">
      	<td><label for="maps_type"><?php _e("Map/Static Type"); ?>:</label></td>
        <td><select name="maps_type">
              <option<?php if ($temp_type == "roadmap") echo " selected=\"selected\""; ?> value="roadmap"><?php _e('Road'); ?></option>
              <option<?php if ($temp_type == "terrain") echo " selected=\"selected\""; ?> value="terrain"><?php _e('Terrain'); ?></option>
              <option<?php if ($temp_type == "hybrid") echo " selected=\"selected\""; ?> value="hybrid"><?php _e('Hybrid'); ?></option>
              <option<?php if ($temp_type == "satellite") echo " selected=\"selected\""; ?> value="satellite"><?php _e('Satellite'); ?></option>
            </select></td>
      </tr>
      <tr class="explain">
      	<td>&nbsp;</td>
      	<td><?php _e("Default Setting is"); ?>: <strong>Road</strong></td>
      </tr>
    	<tr class="settings">
      	<td><label for="maps_zoom"><?php _e('Map/Static Zoom Level'); ?>:</label></td>
        <td><select name="maps_zoom">
              <?php
							$lastTitle = "";
							for ($x = 1; $x < 22; $x++) {
								if ($x == 1)
									echo "<optgroup label=\"" . __("Continent") . "\">\n";
								if ($x == 4)
									echo "<optgroup label=\"" . __("Country") . "\">\n";
								if ($x == 7)
									echo "<optgroup label=\"" . __("Region") . "\">\n";
								if ($x == 10)
									echo "<optgroup label=\"" . __("City") . "\">\n";
								if ($x == 15)
									echo "<optgroup label=\"" . __("Very Close") . "\">\n";
							?>
              <option<?php if ($temp_zoom == $x) echo " selected=\"selected\""; ?> value="<?php echo $x; ?>"><?php echo $x; ?></option>
              <?php
								if ($x == 3)
									echo "</optgroup>\n";
								if ($x == 6)
									echo "</optgroup>\n";
								if ($x == 9)
									echo "</optgroup>\n";
								if ($x == 14)
									echo "</optgroup>\n";
								if ($x == 21)
									echo "</optgroup>\n";
              ?>
              <?php 
							}
							?>
            </select></td>
      </tr>
      <tr class="explain">
      	<td>&nbsp;</td>
      	<td><?php _e('Default Setting is: <strong>10</strong>. Please note, not all Zoom Levels work with both Static Images and iframes. Find a zoom that fits you best.'); ?></td>
      </tr>
    </tbody>
  </table>
  </form>
  <div class="clear"></div>
  <h3 style="width: 100%; text-align:center; margin:auto 0px; margin-top:15px; margin-bottom:10px;"><?php _e("Examples of how to use"); echo " Current Location $CL_Version"; ?></h3>
  <div style="width:47%;float:left;border:1px solid #000;-moz-border-radius:6px;-khtml-border-radius:6px;-webkit-border-radius:6px;border-radius:6px; padding:5px;">
  	<h3><?php _e('How to use the Plugin?');?></h3>
    <p><?php _e('Use this in your template to display your current location: <code>&lt;?php echo display_current_location(); ?&gt;</code>You can choose what to display or by default it will just display City Level. You can pass any of these and they will display in that order.'); ?></p>
    <ul>
      <li><strong>city</strong> :: <?php _e('Display Reverse Geocode (Usually City)'); ?></li>
      <li><strong>coords</strong> :: <?php _e('Display Coordinates'); ?></li>
      <li><strong>accuracy</strong> :: <?php _e('Display Accuracy In Meters'); ?></li>
      <li><strong>date</strong> :: <?php _e('Display Last Updated'); ?></li>
      <li><strong>map</strong> :: <?php _e('Display Map - Little Google Map'); ?></li>
      <li><strong>static</strong> :: <?php _e('Display Static Map - Without Picture Marker'); ?></li>
    </ul>
    <p><?php _e('Note: To display your current location in a post, use the Current Location Options in the new post screen.'); ?></p>
  </div>
  <div style="float:right;width:47%; margin-left:10px;border:1px solid #000;-moz-border-radius:6px;-khtml-border-radius:6px;-webkit-border-radius:6px;border-radius:6px; padding:5px;">
  	<h3><?php _e('Example of the Outputs'); ?></h3>
    <ul>
    	<li><a href="./widgets.php" title="Current Location <?php _e('Widget Access'); ?>"><?php _e('Widget Access'); ?></a></li>
      <li><code>&lt;?php echo display_current_location(); ?&gt;</code> <?php _e('would output this: Nashville, TN, USA'); ?></li>
      <li><code>&lt;?php echo display_current_location("city", "accuracy"); ?&gt;</code> <?php _e('would output this: Nashville, TN, USA<br />2253 m'); ?></li>
      <li><code>&lt;?php echo display_current_location("city", "date", "coords", "accuracy"); ?&gt;</code> <?php _e('would output this: Nashville, TN, USA<br/>Jun 12, 2009 2:34 am<br />-86.682559, 36.085679<br />2253 m'); ?></li>
    </ul>
  </div>
  <div class="clear"></div>
  <script type="text/javascript">
	jQuery(document).ready(function(){
		jQuery('.settings').hover(function() {
			jQuery(this).css('background','#bbd8e7');
			jQuery(this).next('.explain').css('background','#bbd8e7');
		},function() {
			jQuery(this).css('background','#FFFFFF');
			jQuery(this).next('.explain').css('background','#FFFFFF');
		});
		jQuery('.explain').hover(function() {
			jQuery(this).prev('.settings').css('background','#bbd8e7');
			jQuery(this).css('background','#bbd8e7');
		},function() {
			jQuery(this).prev('.settings').css('background','#FFFFFF');
			jQuery(this).css('background','#FFFFFF');
		});
	});
	</script>
</div>
<?php
}


function cl_menu() {
  add_menu_page("Current Location", "Current Location",8, "current-location", "cl_options", WP_PLUGIN_URL.'/'.str_replace(basename(__FILE__),"",plugin_basename(__FILE__)) . 'icon.png');
}
add_action('admin_menu','cl_menu');
?>